{ config, lib, pkgs, ... }:

{
  imports = [
    ./hardware-configuration.nix
    ../desktop.nix
  ];

  boot.loader = {
    systemd-boot.enable = true;
    efi.canTouchEfiVariables = true;
  };

  networking = {
    hostId = "8425e349";
    networkmanager.enable = true;
  };

  modules = {
    desktop = {
      apps = {
        qbittorrent.enable = true;
        thunderbird.enable = true;
      };
      browsers = {
        firefox.enable = true;
      };
      media.graphics = {
        raster.enable = true;
        vector.enable = true;
      };
      office.libreoffice.enable = true;
    };
    dev = {
      node.enable = true;
    };
    editors = {
      neovim.enable = true;
    };
    security = {
      gpg.enable = true;
      pass.enable = true;
    };
    services = {
      borgmatic = {
        enable = true;
        directories = [
          "/home/jordan/Documents"
        ];
        repoPath = "ssh://uzu2y5b1@uzu2y5b1.repo.borgbase.com/./repo";
      };
    };
    shell = {
      git.enable = true;
      zsh.enable = true;
    };
  };

  system.stateVersion = "22.11";
}
